import { Observable as NObservable } from '@nativescript/core/data/observable';
export { ObservableArray } from './observablearray';
export default class Observable extends NObservable {
    onListenerAdded(eventName, count) { }
    onListenerRemoved(eventName, count) { }
    addEventListener(eventNames, callback, thisArg) {
        super.addEventListener(eventNames, callback, thisArg);
        const events = eventNames.split(',');
        for (let i = 0, l = events.length; i < l; i++) {
            const event = events[i].trim();
            const list = this._getEventList(event);
            this.onListenerAdded(event, list ? list.length : 0);
        }
    }
    removeEventListener(eventNames, callback, thisArg) {
        super.removeEventListener(eventNames, callback, thisArg);
        const events = eventNames.split(',');
        for (let i = 0, l = events.length; i < l; i++) {
            const event = events[i].trim();
            const list = this._getEventList(event);
            this.onListenerRemoved(event, list ? list.length : 0);
        }
    }
    on(eventNames, callback, thisArg) {
        super.on(eventNames, callback, thisArg);
        return this;
    }
    once(event, callback, thisArg) {
        const events = event.split(',');
        const cleanup = () => {
            for (let i = 0, l = events.length; i < l; i++) {
                const event = events[i].trim();
                const list = this._getEventList(event);
                this.onListenerRemoved(event, list ? list.length : 0);
            }
        };
        const realCallback = function (data) {
            callback(data);
            cleanup();
        };
        super.once(event, realCallback, thisArg);
        for (let i = 0, l = events.length; i < l; i++) {
            const event = events[i].trim();
            const list = this._getEventList(event);
            this.onListenerAdded(event, list ? list.length : 0);
        }
        return this;
    }
    off(eventNames, callback, thisArg) {
        super.off(eventNames, callback, thisArg);
        return this;
    }
}
//# sourceMappingURL=observable.js.map